<?php
/**
 * Adding fields on the page add/edit categories.
 *
 * @since Wild Book 1.4
 */
 
class Wild_Book_Category_Form_Fields_Setup {

  protected $background_images_option_name = 'wdb_background_image_taxonomies';

  public function setup() {
    add_action( 'admin_enqueue_scripts', array( $this, 'admin_enqueue_scripts' ) );
    
    $taxonomies = array( 'category', 'post_tag' );
    
    foreach( $taxonomies as $taxonomy ) {
      add_action( $taxonomy . '_add_form_fields',  array( $this, 'add_category_form_fields' ) );
      add_action( $taxonomy . '_edit_form_fields', array( $this, 'edit_category_form_fields' ) );
      add_action( 'edited_' . $taxonomy, array( $this, 'save_category_form_fields' ), 10, 2 );
      add_action( 'create_' . $taxonomy, array( $this, 'save_category_form_fields' ), 10, 2 );
    }
  }
  
  /**
	 * Enqueue meta boxes scripts and styles.
	 */	
	public function admin_enqueue_scripts() {
	
    $screen = get_current_screen();

    if( $screen->base == 'edit-tags' || $screen->base == 'term' ) {
      wp_enqueue_media();
      wp_enqueue_script( 'wildbook-custom-background-js',  get_template_directory_uri() . '/js/admin/custom-background.js', array( 'jquery' ), '1.0', true );
      wp_enqueue_style(  'wildbook-custom-background-css', get_template_directory_uri() . '/css/admin/custom-background.css', array(), '1.0');
      
      wp_localize_script( 
        'wildbook-custom-background-js', 
        'wdbVars', 
        array( 
          'mediaFrameTitle'  => esc_html__( 'Select Image', 'wildbook' ),
          'mediaFrameButton' => esc_html__( 'Choose Image', 'wildbook' )
        )
      );  
    }
	}

  public function add_category_form_fields() {
  ?>
    <div class="form-field">
      <label for="wdb-background-image-id"><?php esc_html_e( 'Sidebar Background Image', 'wildbook' ); ?></label>
      
      <div id="wdb-custom-background" class="wdb-custom-background">
        <div id="wdb-selected-background-image" class="wdb-selected-background-image"></div>
        
        <a href="#" id="wdb-set-background-image" class="button set-action"><?php esc_html_e( 'Set a background image', 'wildbook' ); ?></a>
        <a href="#" id="wdb-remove-background-image" class="button remove-action"><?php esc_html_e( 'Remove background image', 'wildbook' ); ?></a>
        
        <input type="hidden" id="wdb-background-image-id" name="background_image_id" value="" />
      </div>
      
      <p><?php esc_html_e( 'Select an image to display on the sidebar.', 'wildbook' ); ?></p>
    </div>
  <?php
  }
  
  public function edit_category_form_fields( $term ) {
    $term_id = $term->term_id;
    $background_image_taxonomies = get_option( $this->background_images_option_name );

    $background_image_id = isset( $background_image_taxonomies[ $term_id ] ) ? absint( $background_image_taxonomies[ $term_id ] ) : '';
  ?>
    <tr class="form-field">
			<th scope="row"><label for="description"><?php esc_html_e( 'Sidebar Background Image', 'wildbook' ); ?></label></th>
			<td>
        <div id="wdb-custom-background" class="wdb-custom-background <?php if( $background_image_id ) :?>selected<?php endif; ?>">
          <div id="wdb-selected-background-image" class="wdb-selected-background-image">
          <?php 
            if( $background_image_id ) { 
              $background_image = wp_get_attachment_image_src( $background_image_id, 'medium' );
              
              if( $background_image ) {
                printf( '<img src="%s" class="background-image" alt="" />', esc_url( $background_image['0'] ) );
              }
            }
            ?>
          </div>
          
          <a href="#" id="wdb-set-background-image" class="button set-action"><?php esc_html_e( 'Set a background image', 'wildbook' ); ?></a>
          <a href="#" id="wdb-remove-background-image" class="button remove-action"><?php esc_html_e( 'Remove', 'wildbook' ); ?></a>
          
          <input type="hidden" id="wdb-background-image-id" name="background_image_id" value="<?php echo $background_image_id; ?>" />
        </div>
      
        <p class="description"><?php esc_html_e( 'Select an image to display on the sidebar.', 'wildbook' ); ?></p>
			</td>
		</tr>
  <?php
  }
  
  public function save_category_form_fields( $term_id ) {
    if ( isset( $_POST['background_image_id'] ) ) {
      $background_image_taxonomies = get_option( $this->background_images_option_name );
      
      if( empty( $background_image_taxonomies ) || ! is_array( $background_image_taxonomies ) )
        $background_image_taxonomies = array();
        
      $background_image_taxonomies[ $term_id ] = absint( $_POST['background_image_id'] );
      update_option( $this->background_images_option_name, $background_image_taxonomies );
    }
  }
}

$wild_book_category_form_fields = new Wild_Book_Category_Form_Fields_Setup();

add_action( 'after_setup_theme', array( $wild_book_category_form_fields, 'setup' ), 16 );
?>