<?php
/**
 * Post options metaboxes.
 *
 * @since Wild Book 1.0
 */
 
class Wild_Book_Metaboxes_Setup {

  protected $custom_background_screens = array( 'post', 'page', 'portfolio' );

  protected $default_page_options = array(
    'display_title' => true,
    'display_share_buttons' => true
  );

  public function setup() {
    add_action( 'admin_enqueue_scripts', array( $this, 'admin_enqueue_scripts' ) );
		add_action( 'add_meta_boxes',        array( $this, 'add_meta_boxes' ) );
		add_action( 'save_post',             array( $this, 'save_post_thumbnail_options' ) );
		add_action( 'save_post',             array( $this, 'save_custom_background_meta' ) );
    add_action( 'save_post',             array( $this, 'save_page_options_meta' ) );
		add_filter( 'admin_post_thumbnail_html', array( $this, 'post_thumbnail_options' ), 10, 2 );
  }
  
  /**
	 * Enqueue meta boxes scripts and styles.
	 */	
	public function admin_enqueue_scripts() {
    $screen = get_current_screen();
    
    if ( ! in_array( $screen->id, $this->custom_background_screens ) )
          return;
          
    wp_enqueue_script( 'wildbook-custom-background-js',  get_template_directory_uri() . '/js/admin/custom-background.js', array( 'jquery' ), '1.0', true );
    wp_enqueue_style(  'wildbook-custom-background-css', get_template_directory_uri() . '/css/admin/custom-background.css', array(), '1.0');
    
    wp_localize_script( 
      'wildbook-custom-background-js', 
      'wdbVars', 
      array( 
        'mediaFrameTitle'  => esc_html__( 'Select Image', 'wildbook' ),
        'mediaFrameButton' => esc_html__( 'Choose Image', 'wildbook' )
      )
    );  
	}
  
  // Add meta boxes
  public function add_meta_boxes() {
    foreach( $this->custom_background_screens as $screen ) {
      add_meta_box( 'custom-background', esc_html__( 'Sidebar Background Image', 'wildbook' ), array( $this, 'custom_background_view' ),  $screen, 'side', 'low' );
    }

    add_meta_box( 'page-options', esc_html__( 'Page Options', 'wildbook' ), array( $this, 'page_options_view' ),  array( 'page' ), 'side' );
  }
  
  public function post_thumbnail_options( $content, $post_id ) {
    $display_post_thumbnail = ( ! metadata_exists( 'post', $post_id, 'display_post_thumbnail' ) ) ? true : get_post_meta( $post_id, 'display_post_thumbnail', true );
    $display_post_thumbnail_archive = ( ! metadata_exists( 'post', $post_id, 'display_post_thumbnail_archive' ) ) ? true : get_post_meta( $post_id, 'display_post_thumbnail_archive', true );

    $post_type = get_post_type( $post_id );
    
    if ( in_array( $post_type, array( 'post', 'portfolio' ) ) ) {
      $content .= '<div class="post-thumbnail-options">' . wp_nonce_field( 'save_post_thumbnail_options', 'post_thumbnail_options_nonce', true, false ) . '<hr />';

      if( $post_type !== 'portfolio' ) {
        $content .= sprintf( '
          <p>
            <label class="selectit"><input value="1" type="checkbox" name="display_post_thumbnail_archive" id="display_post_thumbnail_archive" %s>%s</label>
          </p>',
          $display_post_thumbnail_archive ? 'checked="checked"' : '',
          esc_html__( 'Display on archive pages', 'wildbook' ) 
        );
      }

      $content .= sprintf( '
        <p>
          <label class="selectit"><input value="1" type="checkbox" name="display_post_thumbnail" id="display-post-thumbnail" %s>%s</label>
        </p>',
        $display_post_thumbnail ? 'checked="checked"' : '',
        $post_type == 'portfolio' ? esc_html__( 'Display on project page', 'wildbook' ) : esc_html__( 'Display on single posts', 'wildbook' )
      );

      $content .= '</div>';
    }
    
    return $content;
  }
  
  // Left side background metabox template
  public function custom_background_view( $post ) {
    wp_nonce_field( 'save_custom_background_meta', 'custom_background_meta_box_nonce' );
    
    $custom_background_image_id = get_post_meta( $post->ID, 'left_side_background_image_id', true );
    $custom_background_image = '';
  ?>
    <div id="wdb-custom-background" class="wdb-custom-background <?php if( $custom_background_image_id ) :?>selected<?php endif; ?>">
      <div id="wdb-selected-background-image" class="wdb-selected-background-image">
      <?php 
        if( $custom_background_image_id ) { 
          $custom_background_image = wp_get_attachment_image_src( $custom_background_image_id, 'medium' );
          
          if( $custom_background_image ) {
            printf( '<img src="%s" class="custom-background-image" alt="" />', esc_url( $custom_background_image['0'] ) );
          }
        }
       ?>
      </div>
    
      <a href="#" id="wdb-set-background-image" class="set-action"><?php esc_html_e( 'Set a background image', 'wildbook' ); ?></a>
      <a href="#" id="wdb-remove-background-image" class="remove-action"><?php esc_html_e( 'Remove', 'wildbook' ); ?></a>
    
      <input type="hidden" id="wdb-background-image-id" name="left_side_background_image_id" value="<?php echo absint( $custom_background_image_id ); ?>" />
    </div>
  <?php
  }

  public function page_options_view( $post ) {
    $page_options = get_post_meta( $post->ID, 'wdb_page_options', true );
    $page_options = wp_parse_args( $page_options, $this->default_page_options );
  ?>
    <p>
      <label class="selectit"><input type="checkbox" id="display-title" name="wdb_display_title" <?php checked( $page_options['display_title'], true ); ?>><?php esc_html_e( 'Display page title', 'wildbook' ); ?></label>
    </p>
    <p>
      <label class="selectit"><input type="checkbox" id="display-post-thumbnail" name="wdb_display_share_buttons" <?php checked( $page_options['display_share_buttons'], true ); ?>><?php esc_html_e( 'Display share buttons', 'wildbook' ); ?></label>
    </p>
  <?php
    wp_nonce_field( 'save_page_options_meta', 'page_options_meta_box_nonce' );
  }
  
  // Save post options meta
  public function save_post_thumbnail_options( $post_id ) {
    // Checks save status
    $is_autosave = wp_is_post_autosave( $post_id );
    $is_revision = wp_is_post_revision( $post_id );
    $is_valid_nonce = ( isset( $_POST[ 'post_thumbnail_options_nonce' ] ) && wp_verify_nonce( $_POST[ 'post_thumbnail_options_nonce' ], 'save_post_thumbnail_options' ) ) ? true : false;
 
    // Exits script depending on save status
    if ( $is_autosave || $is_revision || !$is_valid_nonce ) {
        return;
    }

    $display_post_thumbnail = ( isset( $_POST[ 'display_post_thumbnail' ] ) ) ? true : false;
    $display_post_thumbnail_archive = ( isset( $_POST[ 'display_post_thumbnail_archive' ] ) ) ? true : false;
    
    update_post_meta( $post_id, 'display_post_thumbnail_archive', $display_post_thumbnail_archive );
    update_post_meta( $post_id, 'display_post_thumbnail', $display_post_thumbnail );
  }
  
  // Save left side background meta
  public function save_custom_background_meta( $post_id ) {
    // Checks save status
    $is_autosave = wp_is_post_autosave( $post_id );
    $is_revision = wp_is_post_revision( $post_id );
    $is_valid_nonce = ( isset( $_POST[ 'custom_background_meta_box_nonce' ] ) && wp_verify_nonce( $_POST[ 'custom_background_meta_box_nonce' ], 'save_custom_background_meta' ) ) ? true : false;
 
    // Exits script depending on save status
    if ( $is_autosave || $is_revision || !$is_valid_nonce ) {
        return;
    }

    if( isset( $_POST[ 'left_side_background_image_id' ] ) ) {
      update_post_meta( $post_id, 'left_side_background_image_id', absint( $_POST[ 'left_side_background_image_id' ] ) );
    }
  }

  // Save page options meta
  public function save_page_options_meta( $post_id ) {
    $is_autosave = wp_is_post_autosave( $post_id );
    $is_revision = wp_is_post_revision( $post_id );
    $is_valid_nonce = ( isset( $_POST[ 'page_options_meta_box_nonce' ] ) && wp_verify_nonce( $_POST[ 'page_options_meta_box_nonce' ], 'save_page_options_meta' ) ) ? true : false;
 
    if ( $is_autosave || $is_revision || !$is_valid_nonce ) {
        return;
    }

    $display_title = ( isset( $_POST[ 'wdb_display_title' ] ) ) ? true : false;
    $display_share_buttons = ( isset( $_POST[ 'wdb_display_share_buttons' ] ) ) ? true : false;

    update_post_meta( $post_id, 'wdb_page_options', compact( 'display_title', 'display_share_buttons' ) );
  }
}

$wild_book_metaboxes = new Wild_Book_Metaboxes_Setup();

add_action( 'after_setup_theme', array( $wild_book_metaboxes, 'setup' ), 16 );
?>